@@ -15,6 +15,8 @@
 
 import functools
 import os
+from os.path import isdir  # tighter scoped import for mocking
+import time
 
 import six
 from six.moves.configparser import ConfigParser, NoSectionError, NoOptionError
@@ -103,11 +105,6 @@ reload_constraints()
 MAX_BUFFERED_SLO_SEGMENTS = 10000
 
 
-#: Query string format= values to their corresponding content-type values
-FORMAT2CONTENT_TYPE = {'plain': 'text/plain', 'json': 'application/json',
-                       'xml': 'application/xml'}
-
-
 # By default the maximum number of allowed headers depends on the number of max
 # allowed metadata settings plus a default value of 36 for swift internally
 # generated headers and regular http headers.  If for some reason this is not
@@ -233,9 +230,9 @@ def check_dir(root, drive):
 
     :param root:  base path where the dir is
     :param drive: drive name to be checked
-    :returns: True if it is a valid directoy, False otherwise
+    :returns: full path to the device, or None if drive fails to validate
     """
-    return os.path.isdir(os.path.join(root, drive))
+    return check_drive(root, drive, False)
 
 
 def check_mount(root, drive):
@@ -247,12 +244,31 @@ def check_mount(root, drive):
 
     :param root:  base path where the devices are mounted
     :param drive: drive name to be checked
-    :returns: True if it is a valid mounted device, False otherwise
+    :returns: full path to the device, or None if drive fails to validate
+    """
+    return check_drive(root, drive, True)
+
+
+def check_drive(root, drive, mount_check):
+    """
+    Validate the path given by root and drive is a valid existing directory.
+
+    :param root:  base path where the devices are mounted
+    :param drive: drive name to be checked
+    :param mount_check: additionally require path is mounted
+
+    :returns: full path to the device, or None if drive fails to validate
     """
     if not (urllib.parse.quote_plus(drive) == drive):
-        return False
+        return None
     path = os.path.join(root, drive)
-    return utils.ismount(path)
+    if mount_check:
+        if utils.ismount(path):
+            return path
+    else:
+        if isdir(path):
+            return path
+    return None
 
 
 def check_float(string):
@@ -296,7 +312,6 @@ def check_delete_headers(request):
     :returns: HTTPBadRequest in case of invalid values
               or None if values are ok
     """
-    now = float(valid_timestamp(request))
     if 'x-delete-after' in request.headers:
         try:
             x_delete_after = int(request.headers['x-delete-after'])
@@ -304,14 +319,13 @@ def check_delete_headers(request):
             raise HTTPBadRequest(request=request,
                                  content_type='text/plain',
                                  body='Non-integer X-Delete-After')
-        actual_del_time = now + x_delete_after
-        if actual_del_time < now:
+        actual_del_time = time.time() + x_delete_after
+        if actual_del_time < time.time():
             raise HTTPBadRequest(request=request,
                                  content_type='text/plain',
                                  body='X-Delete-After in past')
         request.headers['x-delete-at'] = utils.normalize_delete_at_timestamp(
             actual_del_time)
-        del request.headers['x-delete-after']
 
     if 'x-delete-at' in request.headers:
         try:
@@ -321,7 +335,7 @@ def check_delete_headers(request):
             raise HTTPBadRequest(request=request, content_type='text/plain',
                                  body='Non-integer X-Delete-At')
 
-        if x_delete_at < now and not utils.config_true_value(
+        if x_delete_at < time.time() and not utils.config_true_value(
                 request.headers.get('x-backend-replication', 'f')):
             raise HTTPBadRequest(request=request, content_type='text/plain',
                                  body='X-Delete-At in past')
