@@ -105,6 +105,10 @@ class DiskFileXattrNotSupported(DiskFileError):
     pass
 
 
+class DiskFileBadMetadataChecksum(DiskFileError):
+    pass
+
+
 class DeviceUnavailable(SwiftException):
     pass
 
@@ -145,6 +149,10 @@ class LockTimeout(MessageTimeout):
     pass
 
 
+class RingLoadError(SwiftException):
+    pass
+
+
 class RingBuilderError(SwiftException):
     pass
 
@@ -207,6 +215,10 @@ class APIVersionError(SwiftException):
     pass
 
 
+class EncryptionException(SwiftException):
+    pass
+
+
 class ClientException(Exception):
 
     def __init__(self, msg, http_scheme='', http_host='', http_port='',
