@@ -412,12 +412,7 @@ def run_server(conf, logger, sock, global_conf=None):
     wsgi.WRITE_TIMEOUT = int(conf.get('client_timeout') or 60)
 
     eventlet.hubs.use_hub(get_hub())
-    # NOTE(sileht):
-    #     monkey-patching thread is required by python-keystoneclient;
-    #     monkey-patching select is required by oslo.messaging pika driver
-    #         if thread is monkey-patched.
-    eventlet.patcher.monkey_patch(all=False, socket=True, select=True,
-                                  thread=True)
+    utils.eventlet_monkey_patch()
     eventlet_debug = config_true_value(conf.get('eventlet_debug', 'no'))
     eventlet.debug.hub_exceptions(eventlet_debug)
     wsgi_logger = NullLogger()
