@@ -50,9 +50,10 @@ class AuditorWorker(object):
             # configure for their replicator
             replicator_config = readconf(self.conf['__file__'],
                                          'object-replicator')
-        except (KeyError, SystemExit):
+        except (KeyError, ValueError, IOError):
             # if we can't parse the real config (generally a KeyError on
-            # __file__, or SystemExit on no object-replicator section) we use
+            # __file__, or ValueError on no object-replicator section, or
+            # IOError if reading the file failed) we use
             # a very conservative default for rsync_timeout
             default_rsync_timeout = 86400
         else:
@@ -288,9 +289,9 @@ class AuditorWorker(object):
 class ObjectAuditor(Daemon):
     """Audit objects."""
 
-    def __init__(self, conf, **options):
+    def __init__(self, conf, logger=None, **options):
         self.conf = conf
-        self.logger = get_logger(conf, log_route='object-auditor')
+        self.logger = logger or get_logger(conf, log_route='object-auditor')
         self.devices = conf.get('devices', '/srv/node')
         self.concurrency = int(conf.get('concurrency', 1))
         self.conf_zero_byte_fps = int(
