@@ -40,8 +40,11 @@ def tearDownModule():
 class TestObject(unittest2.TestCase):
 
     def setUp(self):
-        if tf.skip:
+        if tf.skip or tf.skip2:
             raise SkipTest
+
+        if tf.in_process:
+            tf.skip_if_no_xattrs()
         self.container = uuid4().hex
 
         self.containers = []
@@ -379,7 +382,7 @@ class TestObject(unittest2.TestCase):
                                               'x_delete_after'),
                          '', {'X-Auth-Token': token,
                               'Content-Length': '0',
-                              'X-Delete-After': '1'})
+                              'X-Delete-After': '2'})
             return check_response(conn)
         resp = retry(put)
         resp.read()
@@ -400,7 +403,7 @@ class TestObject(unittest2.TestCase):
             resp = retry(get)
             resp.read()
             count += 1
-            time.sleep(1)
+            time.sleep(0.5)
 
         self.assertEqual(resp.status, 404)
 
@@ -583,7 +586,7 @@ class TestObject(unittest2.TestCase):
         self.assertIn(resp.status, (204, 404))
 
     def test_copy_between_accounts(self):
-        if tf.skip:
+        if tf.skip2:
             raise SkipTest
 
         source = '%s/%s' % (self.container, self.obj)
