@@ -220,21 +220,9 @@ class TestSlo(Base):
                 "Expected slo_enabled to be True/False, got %r" %
                 (self.env.slo_enabled,))
 
-        manifest_abcde_hash = hashlib.md5()
-        manifest_abcde_hash.update(hashlib.md5('a' * 1024 * 1024).hexdigest())
-        manifest_abcde_hash.update(hashlib.md5('b' * 1024 * 1024).hexdigest())
-        manifest_abcde_hash.update(hashlib.md5('c' * 1024 * 1024).hexdigest())
-        manifest_abcde_hash.update(hashlib.md5('d' * 1024 * 1024).hexdigest())
-        manifest_abcde_hash.update(hashlib.md5('e').hexdigest())
-        self.manifest_abcde_etag = manifest_abcde_hash.hexdigest()
-
     def test_slo_get_simple_manifest(self):
         file_item = self.env.container.file('manifest-abcde')
         file_contents = file_item.read()
-        self.assertEqual(file_item.conn.response.status, 200)
-        headers = dict(file_item.conn.response.getheaders())
-        self.assertIn('etag', headers)
-        self.assertEqual(headers['etag'], '"%s"' % self.manifest_abcde_etag)
         self.assertEqual(4 * 1024 * 1024 + 1, len(file_contents))
         self.assertEqual('a', file_contents[0])
         self.assertEqual('a', file_contents[1024 * 1024 - 1])
@@ -361,10 +349,6 @@ class TestSlo(Base):
         file_item = self.env.container.file('manifest-abcde')
         file_contents = file_item.read(size=1024 * 1024 + 2,
                                        offset=1024 * 1024 - 1)
-        self.assertEqual(file_item.conn.response.status, 206)
-        headers = dict(file_item.conn.response.getheaders())
-        self.assertIn('etag', headers)
-        self.assertEqual(headers['etag'], '"%s"' % self.manifest_abcde_etag)
         self.assertEqual('a', file_contents[0])
         self.assertEqual('b', file_contents[1])
         self.assertEqual('b', file_contents[-2])
@@ -435,10 +419,16 @@ class TestSlo(Base):
         self.assertEqual('d', file_contents[-1])
 
     def test_slo_etag_is_hash_of_etags(self):
-        # we have this check in test_slo_get_simple_manifest, too,
-        # but verify that it holds for HEAD requests
+        expected_hash = hashlib.md5()
+        expected_hash.update(hashlib.md5('a' * 1024 * 1024).hexdigest())
+        expected_hash.update(hashlib.md5('b' * 1024 * 1024).hexdigest())
+        expected_hash.update(hashlib.md5('c' * 1024 * 1024).hexdigest())
+        expected_hash.update(hashlib.md5('d' * 1024 * 1024).hexdigest())
+        expected_hash.update(hashlib.md5('e').hexdigest())
+        expected_etag = expected_hash.hexdigest()
+
         file_item = self.env.container.file('manifest-abcde')
-        self.assertEqual(self.manifest_abcde_etag, file_item.info()['etag'])
+        self.assertEqual(expected_etag, file_item.info()['etag'])
 
     def test_slo_etag_is_hash_of_etags_submanifests(self):
 
@@ -802,6 +792,101 @@ class TestSlo(Base):
         except ValueError:
             self.fail("COPY didn't copy the manifest (invalid json on GET)")
 
+    def test_slo_put_heartbeating(self):
+        if 'yield_frequency' not in cluster_info['slo']:
+            # old swift?
+            raise SkipTest('Swift does not seem to support heartbeating')
+
+        def do_put(headers=None, include_error=False):
+            file_item = self.env.container.file("manifest-heartbeat")
+            seg_info = self.env.seg_info
+            manifest_data = [seg_info['seg_a'], seg_info['seg_b'],
+                             seg_info['seg_c'], seg_info['seg_d'],
+                             seg_info['seg_e']]
+            if include_error:
+                manifest_data.append({'path': 'non-existent/segment'})
+            resp = file_item.write(
+                json.dumps(manifest_data),
+                parms={'multipart-manifest': 'put', 'heartbeat': 'on'},
+                hdrs=headers, return_resp=True)
+            self.assertEqual(resp.status, 202)
+            self.assertTrue(resp.chunked)
+            body_lines = resp.body.split('\n', 2)
+            self.assertFalse(body_lines[0].strip())  # all whitespace
+            self.assertEqual('\r', body_lines[1])
+            return body_lines[2]
+
+        body_lines = do_put().split('\n')
+        self.assertIn('Response Status: 201 Created', body_lines)
+        self.assertIn('Etag', [line.split(':', 1)[0] for line in body_lines])
+        self.assertIn('Last Modified', [line.split(':', 1)[0]
+                                        for line in body_lines])
+
+        body_lines = do_put({'Accept': 'text/plain'}).split('\n')
+        self.assertIn('Response Status: 201 Created', body_lines)
+        self.assertIn('Etag', [line.split(':', 1)[0] for line in body_lines])
+        self.assertIn('Last Modified', [line.split(':', 1)[0]
+                                        for line in body_lines])
+
+        body = do_put({'Accept': 'application/json'})
+        try:
+            resp = json.loads(body)
+        except ValueError:
+            self.fail('Expected JSON, got %r' % body)
+        self.assertIn('Etag', resp)
+        del resp['Etag']
+        self.assertIn('Last Modified', resp)
+        del resp['Last Modified']
+        self.assertEqual(resp, {
+            'Response Status': '201 Created',
+            'Response Body': '',
+            'Errors': [],
+        })
+
+        body_lines = do_put(include_error=True).split('\n')
+        self.assertIn('Response Status: 400 Bad Request', body_lines)
+        self.assertIn('Response Body: Bad Request', body_lines)
+        self.assertNotIn('Etag', [line.split(':', 1)[0]
+                                  for line in body_lines])
+        self.assertNotIn('Last Modified', [line.split(':', 1)[0]
+                                           for line in body_lines])
+        self.assertEqual(body_lines[-3:], [
+            'Errors:',
+            'non-existent/segment, 404 Not Found',
+            '',
+        ])
+
+        body = do_put({'Accept': 'application/json'}, include_error=True)
+        try:
+            resp = json.loads(body)
+        except ValueError:
+            self.fail('Expected JSON, got %r' % body)
+        self.assertNotIn('Etag', resp)
+        self.assertNotIn('Last Modified', resp)
+        self.assertEqual(resp, {
+            'Response Status': '400 Bad Request',
+            'Response Body': 'Bad Request\nThe server could not comply with '
+                             'the request since it is either malformed or '
+                             'otherwise incorrect.',
+            'Errors': [
+                ['non-existent/segment', '404 Not Found'],
+            ],
+        })
+
+        body = do_put({'Accept': 'application/json', 'ETag': 'bad etag'})
+        try:
+            resp = json.loads(body)
+        except ValueError:
+            self.fail('Expected JSON, got %r' % body)
+        self.assertNotIn('Etag', resp)
+        self.assertNotIn('Last Modified', resp)
+        self.assertEqual(resp, {
+            'Response Status': '422 Unprocessable Entity',
+            'Response Body': 'Unprocessable Entity\nUnable to process the '
+                             'contained instructions',
+            'Errors': [],
+        })
+
     def _make_manifest(self):
         file_item = self.env.container.file("manifest-post")
         seg_info = self.env.seg_info
