@@ -24,7 +24,6 @@ from collections import defaultdict
 import unittest
 from hashlib import md5
 from uuid import uuid4
-from nose import SkipTest
 
 from six.moves.http_client import HTTPConnection
 import shutil
@@ -204,12 +203,12 @@ def get_ring(ring_name, required_replicas, required_devices,
         return ring
     # easy sanity checks
     if ring.replica_count != required_replicas:
-        raise SkipTest('%s has %s replicas instead of %s' % (
+        raise unittest.SkipTest('%s has %s replicas instead of %s' % (
             ring.serialized_path, ring.replica_count, required_replicas))
 
     devs = [dev for dev in ring.devs if dev is not None]
     if len(devs) != required_devices:
-        raise SkipTest('%s has %s devices instead of %s' % (
+        raise unittest.SkipTest('%s has %s devices instead of %s' % (
             ring.serialized_path, len(devs), required_devices))
     for dev in devs:
         # verify server is exposing mounted device
@@ -221,12 +220,12 @@ def get_ring(ring_name, required_replicas, required_devices,
                 dev_path = os.path.join(conf['devices'], device)
                 full_path = os.path.realpath(dev_path)
                 if not os.path.exists(full_path):
-                    raise SkipTest(
+                    raise unittest.SkipTest(
                         'device %s in %s was not found (%s)' %
                         (device, conf['devices'], full_path))
                 break
         else:
-            raise SkipTest(
+            raise unittest.SkipTest(
                 "unable to find ring device %s under %s's devices (%s)" % (
                     dev['device'], server, conf['devices']))
         # verify server is exposing rsync device
@@ -237,15 +236,15 @@ def get_ring(ring_name, required_replicas, required_devices,
         p = Popen(cmd, shell=True, stdout=PIPE)
         stdout, _stderr = p.communicate()
         if p.returncode:
-            raise SkipTest('unable to connect to rsync '
-                           'export %s (%s)' % (rsync_export, cmd))
+            raise unittest.SkipTest('unable to connect to rsync '
+                                    'export %s (%s)' % (rsync_export, cmd))
         for line in stdout.splitlines():
             if line.rsplit(None, 1)[-1] == dev['device']:
                 break
         else:
-            raise SkipTest("unable to find ring device %s under rsync's "
-                           "exported devices for %s (%s)" %
-                           (dev['device'], rsync_export, cmd))
+            raise unittest.SkipTest("unable to find ring device %s under "
+                                    "rsync's exported devices for %s (%s)" %
+                                    (dev['device'], rsync_export, cmd))
     return ring
 
 
@@ -264,7 +263,7 @@ def get_policy(**kwargs):
                 matches = False
         if matches:
             return policy
-    raise SkipTest('No policy matching %s' % kwargs)
+    raise unittest.SkipTest('No policy matching %s' % kwargs)
 
 
 def resetswift():
@@ -444,11 +443,11 @@ class ProbeTest(unittest.TestCase):
     def revive_drive(self, device):
         disabled_name = device + "X"
         if os.path.isdir(disabled_name):
-            renamer(device + "X", device)
+            renamer(disabled_name, device)
         else:
             os.system('sudo mount %s' % device)
 
-    def make_internal_client(self, object_post_as_copy=True):
+    def make_internal_client(self):
         tempdir = mkdtemp()
         try:
             conf_path = os.path.join(tempdir, 'internal_client.conf')
@@ -464,14 +463,13 @@ class ProbeTest(unittest.TestCase):
 
             [filter:copy]
             use = egg:swift#copy
-            object_post_as_copy = %s
 
             [filter:cache]
             use = egg:swift#memcache
 
             [filter:catch_errors]
             use = egg:swift#catch_errors
-            """ % object_post_as_copy
+            """
             with open(conf_path, 'w') as f:
                 f.write(dedent(conf_body))
             return internal_client.InternalClient(conf_path, 'test', 1)
@@ -502,13 +500,13 @@ if __name__ == "__main__":
         try:
             get_ring(server, 3, 4,
                      force_validate=True)
-        except SkipTest as err:
+        except unittest.SkipTest as err:
             sys.exit('%s ERROR: %s' % (server, err))
         print('%s OK' % server)
     for policy in POLICIES:
         try:
             get_ring(policy.ring_name, 3, 4,
                      server='object', force_validate=True)
-        except SkipTest as err:
+        except unittest.SkipTest as err:
             sys.exit('object ERROR (%s): %s' % (policy.name, err))
         print('object OK (%s)' % policy.name)
