@@ -16,7 +16,6 @@ import base64
 import json
 import os
 import unittest
-from xml.dom import minidom
 
 import mock
 
@@ -961,138 +960,6 @@ class TestDecrypterContainerRequests(unittest.TestCase):
         self.assertIn("Cipher must be AES_CTR_256",
                       self.decrypter.logger.get_lines_for_level('error')[0])
 
-    def _assert_element(self, name, expected, element):
-        self.assertEqual(element.tagName, name)
-        self._assert_element_contains_dict(expected, element)
-
-    def _assert_element_contains_dict(self, expected, element):
-        for k, v in expected.items():
-            entry = element.getElementsByTagName(k)
-            self.assertIsNotNone(entry, 'Key %s not found' % k)
-            actual = entry[0].childNodes[0].nodeValue
-            self.assertEqual(v, actual,
-                             "Expected %s but got %s for key %s"
-                             % (v, actual, k))
-
-    def test_GET_container_xml(self):
-        content_type_1 = u'\uF10F\uD20D\uB30B\u9409'
-        content_type_2 = 'text/plain; param=foo'
-        pt_etag1 = 'c6e8196d7f0fff6444b90861fe8d609d'
-        pt_etag2 = 'ac0374ed4d43635f803c82469d0b5a10'
-        key = fetch_crypto_keys()['container']
-
-        fake_body = '''<?xml version="1.0" encoding="UTF-8"?>
-<container name="testc">\
-<subdir name="test-subdir"><name>test-subdir</name></subdir>\
-<object><hash>\
-''' + encrypt_and_append_meta(pt_etag1.encode('utf8'), key) + '''\
-</hash><content_type>\
-''' + content_type_1 + '''\
-</content_type><name>testfile</name><bytes>16</bytes>\
-<last_modified>2015-04-19T02:37:39.601660</last_modified></object>\
-<object><hash>\
-''' + encrypt_and_append_meta(pt_etag2.encode('utf8'), key) + '''\
-</hash><content_type>\
-''' + content_type_2 + '''\
-</content_type><name>testfile2</name><bytes>24</bytes>\
-<last_modified>2015-04-19T02:37:39.684740</last_modified></object>\
-</container>'''
-
-        resp = self._make_cont_get_req(fake_body, 'xml')
-        self.assertEqual('200 OK', resp.status)
-        body = resp.body
-        self.assertEqual(len(body), int(resp.headers['Content-Length']))
-
-        tree = minidom.parseString(body)
-        containers = tree.getElementsByTagName('container')
-        self.assertEqual(1, len(containers))
-        self.assertEqual('testc',
-                         containers[0].attributes.getNamedItem("name").value)
-
-        results = containers[0].childNodes
-        self.assertEqual(3, len(results))
-
-        self._assert_element('subdir', {"name": "test-subdir"}, results[0])
-
-        obj_dict_1 = {"bytes": "16",
-                      "last_modified": "2015-04-19T02:37:39.601660",
-                      "hash": pt_etag1,
-                      "name": "testfile",
-                      "content_type": content_type_1}
-        self._assert_element('object', obj_dict_1, results[1])
-        obj_dict_2 = {"bytes": "24",
-                      "last_modified": "2015-04-19T02:37:39.684740",
-                      "hash": pt_etag2,
-                      "name": "testfile2",
-                      "content_type": content_type_2}
-        self._assert_element('object', obj_dict_2, results[2])
-
-    def test_GET_container_xml_with_crypto_override(self):
-        content_type_1 = 'image/jpeg'
-        content_type_2 = 'text/plain; param=foo'
-
-        fake_body = '''<?xml version="1.0" encoding="UTF-8"?>
-<container name="testc">\
-<object><hash>c6e8196d7f0fff6444b90861fe8d609d</hash>\
-<content_type>''' + content_type_1 + '''\
-</content_type><name>testfile</name><bytes>16</bytes>\
-<last_modified>2015-04-19T02:37:39.601660</last_modified></object>\
-<object><hash>ac0374ed4d43635f803c82469d0b5a10</hash>\
-<content_type>''' + content_type_2 + '''\
-</content_type><name>testfile2</name><bytes>24</bytes>\
-<last_modified>2015-04-19T02:37:39.684740</last_modified></object>\
-</container>'''
-
-        resp = self._make_cont_get_req(fake_body, 'xml', override=True)
-
-        self.assertEqual('200 OK', resp.status)
-        body = resp.body
-        self.assertEqual(len(body), int(resp.headers['Content-Length']))
-
-        tree = minidom.parseString(body)
-        containers = tree.getElementsByTagName('container')
-        self.assertEqual(1, len(containers))
-        self.assertEqual('testc',
-                         containers[0].attributes.getNamedItem("name").value)
-
-        objs = tree.getElementsByTagName('object')
-        self.assertEqual(2, len(objs))
-
-        obj_dict_1 = {"bytes": "16",
-                      "last_modified": "2015-04-19T02:37:39.601660",
-                      "hash": "c6e8196d7f0fff6444b90861fe8d609d",
-                      "name": "testfile",
-                      "content_type": content_type_1}
-        self._assert_element_contains_dict(obj_dict_1, objs[0])
-        obj_dict_2 = {"bytes": "24",
-                      "last_modified": "2015-04-19T02:37:39.684740",
-                      "hash": "ac0374ed4d43635f803c82469d0b5a10",
-                      "name": "testfile2",
-                      "content_type": content_type_2}
-        self._assert_element_contains_dict(obj_dict_2, objs[1])
-
-    def test_cont_get_xml_req_with_cipher_mismatch(self):
-        bad_crypto_meta = fake_get_crypto_meta()
-        bad_crypto_meta['cipher'] = 'unknown_cipher'
-
-        fake_body = '''<?xml version="1.0" encoding="UTF-8"?>
-<container name="testc"><object>\
-<hash>''' + encrypt_and_append_meta('c6e8196d7f0fff6444b90861fe8d609d',
-                                    fetch_crypto_keys()['container'],
-                                    crypto_meta=bad_crypto_meta) + '''\
-</hash>\
-<content_type>image/jpeg</content_type>\
-<name>testfile</name><bytes>16</bytes>\
-<last_modified>2015-04-19T02:37:39.601660</last_modified></object>\
-</container>'''
-
-        resp = self._make_cont_get_req(fake_body, 'xml')
-
-        self.assertEqual('500 Internal Error', resp.status)
-        self.assertEqual('Error decrypting container listing', resp.body)
-        self.assertIn("Cipher must be AES_CTR_256",
-                      self.decrypter.logger.get_lines_for_level('error')[0])
-
 
 class TestModuleMethods(unittest.TestCase):
     def test_purge_crypto_sysmeta_headers(self):
