@@ -19,7 +19,8 @@ import tempfile
 import time
 
 from six.moves import range
-from test.unit import MockTrue
+from test import safe_repr
+from test.unit import mock_check_drive
 
 from swift.common.swob import Request, HTTPException
 from swift.common.http import HTTP_REQUEST_ENTITY_TOO_LARGE, \
@@ -29,6 +30,14 @@ from swift.common.constraints import MAX_OBJECT_NAME_LENGTH
 
 
 class TestConstraints(unittest.TestCase):
+
+    def assertIn(self, member, container, msg=None):
+        """Copied from 2.7"""
+        if member not in container:
+            standardMsg = '%s not found in %s' % (safe_repr(member),
+                                                  safe_repr(container))
+            self.fail(self._formatMessage(msg, standardMsg))
+
     def test_check_metadata_empty(self):
         headers = {}
         self.assertIsNone(constraints.check_metadata(Request.blank(
@@ -136,57 +145,49 @@ class TestConstraints(unittest.TestCase):
 
     def test_check_object_creation_content_length(self):
         headers = {'Content-Length': str(constraints.MAX_FILE_SIZE),
-                   'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': 'text/plain'}
         self.assertIsNone(constraints.check_object_creation(Request.blank(
             '/', headers=headers), 'object_name'))
 
         headers = {'Content-Length': str(constraints.MAX_FILE_SIZE + 1),
-                   'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': 'text/plain'}
         resp = constraints.check_object_creation(
             Request.blank('/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_REQUEST_ENTITY_TOO_LARGE)
 
         headers = {'Transfer-Encoding': 'chunked',
-                   'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': 'text/plain'}
         self.assertIsNone(constraints.check_object_creation(Request.blank(
             '/', headers=headers), 'object_name'))
 
         headers = {'Transfer-Encoding': 'gzip',
-                   'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': 'text/plain'}
         resp = constraints.check_object_creation(Request.blank(
             '/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_BAD_REQUEST)
         self.assertIn('Invalid Transfer-Encoding header value', resp.body)
 
-        headers = {'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+        headers = {'Content-Type': 'text/plain'}
         resp = constraints.check_object_creation(
             Request.blank('/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_LENGTH_REQUIRED)
 
         headers = {'Content-Length': 'abc',
-                   'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': 'text/plain'}
         resp = constraints.check_object_creation(Request.blank(
             '/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_BAD_REQUEST)
         self.assertIn('Invalid Content-Length header value', resp.body)
 
         headers = {'Transfer-Encoding': 'gzip,chunked',
-                   'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': 'text/plain'}
         resp = constraints.check_object_creation(Request.blank(
             '/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_NOT_IMPLEMENTED)
 
     def test_check_object_creation_name_length(self):
         headers = {'Transfer-Encoding': 'chunked',
-                   'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': 'text/plain'}
         name = 'o' * constraints.MAX_OBJECT_NAME_LENGTH
         self.assertIsNone(constraints.check_object_creation(Request.blank(
             '/', headers=headers), name))
@@ -201,13 +202,11 @@ class TestConstraints(unittest.TestCase):
 
     def test_check_object_creation_content_type(self):
         headers = {'Transfer-Encoding': 'chunked',
-                   'Content-Type': 'text/plain',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': 'text/plain'}
         self.assertIsNone(constraints.check_object_creation(Request.blank(
             '/', headers=headers), 'object_name'))
 
-        headers = {'Transfer-Encoding': 'chunked',
-                   'X-Timestamp': str(time.time())}
+        headers = {'Transfer-Encoding': 'chunked'}
         resp = constraints.check_object_creation(
             Request.blank('/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_BAD_REQUEST)
@@ -215,143 +214,140 @@ class TestConstraints(unittest.TestCase):
 
     def test_check_object_creation_bad_content_type(self):
         headers = {'Transfer-Encoding': 'chunked',
-                   'Content-Type': '\xff\xff',
-                   'X-Timestamp': str(time.time())}
+                   'Content-Type': '\xff\xff'}
         resp = constraints.check_object_creation(
             Request.blank('/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('Content-Type', resp.body)
+        self.assertTrue('Content-Type' in resp.body)
 
     def test_check_object_creation_bad_delete_headers(self):
         headers = {'Transfer-Encoding': 'chunked',
                    'Content-Type': 'text/plain',
-                   'X-Delete-After': 'abc',
-                   'X-Timestamp': str(time.time())}
+                   'X-Delete-After': 'abc'}
         resp = constraints.check_object_creation(
             Request.blank('/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('Non-integer X-Delete-After', resp.body)
+        self.assertTrue('Non-integer X-Delete-After' in resp.body)
 
         t = str(int(time.time() - 60))
         headers = {'Transfer-Encoding': 'chunked',
                    'Content-Type': 'text/plain',
-                   'X-Delete-At': t,
-                   'X-Timestamp': str(time.time())}
+                   'X-Delete-At': t}
         resp = constraints.check_object_creation(
             Request.blank('/', headers=headers), 'object_name')
         self.assertEqual(resp.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('X-Delete-At in past', resp.body)
+        self.assertTrue('X-Delete-At in past' in resp.body)
 
     def test_check_delete_headers(self):
-        # x-delete-at value should be relative to the request timestamp rather
-        # than time.time() so separate the two to ensure the checks are robust
-        ts = time.time() + 100
 
         # X-Delete-After
-        headers = {'X-Delete-After': '600',
-                   'X-Timestamp': str(ts)}
-        req = constraints.check_delete_headers(
+        headers = {'X-Delete-After': '60'}
+        resp = constraints.check_delete_headers(
             Request.blank('/', headers=headers))
-        self.assertIsInstance(req, Request)
-        self.assertIn('x-delete-at', req.headers)
-        self.assertNotIn('x-delete-after', req.headers)
-        expected_delete_at = str(int(ts) + 600)
-        self.assertEqual(req.headers.get('X-Delete-At'), expected_delete_at)
+        self.assertTrue(isinstance(resp, Request))
+        self.assertTrue('x-delete-at' in resp.headers)
 
-        headers = {'X-Delete-After': 'abc',
-                   'X-Timestamp': str(time.time())}
-
-        with self.assertRaises(HTTPException) as cm:
-            constraints.check_delete_headers(
+        headers = {'X-Delete-After': 'abc'}
+        try:
+            resp = constraints.check_delete_headers(
                 Request.blank('/', headers=headers))
-        self.assertEqual(cm.exception.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('Non-integer X-Delete-After', cm.exception.body)
+        except HTTPException as e:
+            self.assertEqual(e.status_int, HTTP_BAD_REQUEST)
+            self.assertTrue('Non-integer X-Delete-After' in e.body)
+        else:
+            self.fail("Should have failed with HTTPBadRequest")
 
-        headers = {'X-Delete-After': '60.1',
-                   'X-Timestamp': str(time.time())}
-        with self.assertRaises(HTTPException) as cm:
-            constraints.check_delete_headers(
+        headers = {'X-Delete-After': '60.1'}
+        try:
+            resp = constraints.check_delete_headers(
                 Request.blank('/', headers=headers))
-        self.assertEqual(cm.exception.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('Non-integer X-Delete-After', cm.exception.body)
+        except HTTPException as e:
+            self.assertEqual(e.status_int, HTTP_BAD_REQUEST)
+            self.assertTrue('Non-integer X-Delete-After' in e.body)
+        else:
+            self.fail("Should have failed with HTTPBadRequest")
 
-        headers = {'X-Delete-After': '-1',
-                   'X-Timestamp': str(time.time())}
-        with self.assertRaises(HTTPException) as cm:
-            constraints.check_delete_headers(
+        headers = {'X-Delete-After': '-1'}
+        try:
+            resp = constraints.check_delete_headers(
                 Request.blank('/', headers=headers))
-        self.assertEqual(cm.exception.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('X-Delete-After in past', cm.exception.body)
+        except HTTPException as e:
+            self.assertEqual(e.status_int, HTTP_BAD_REQUEST)
+            self.assertTrue('X-Delete-After in past' in e.body)
+        else:
+            self.fail("Should have failed with HTTPBadRequest")
 
         # X-Delete-At
-        delete_at = str(int(ts + 100))
-        headers = {'X-Delete-At': delete_at,
-                   'X-Timestamp': str(ts)}
-        req = constraints.check_delete_headers(
+        t = str(int(time.time() + 100))
+        headers = {'X-Delete-At': t}
+        resp = constraints.check_delete_headers(
             Request.blank('/', headers=headers))
-        self.assertIsInstance(req, Request)
-        self.assertIn('x-delete-at', req.headers)
-        self.assertEqual(req.headers.get('X-Delete-At'), delete_at)
+        self.assertTrue(isinstance(resp, Request))
+        self.assertTrue('x-delete-at' in resp.headers)
+        self.assertEqual(resp.headers.get('X-Delete-At'), t)
 
-        headers = {'X-Delete-At': 'abc',
-                   'X-Timestamp': str(ts)}
-        with self.assertRaises(HTTPException) as cm:
-            constraints.check_delete_headers(
+        headers = {'X-Delete-At': 'abc'}
+        try:
+            resp = constraints.check_delete_headers(
                 Request.blank('/', headers=headers))
-        self.assertEqual(cm.exception.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('Non-integer X-Delete-At', cm.exception.body)
+        except HTTPException as e:
+            self.assertEqual(e.status_int, HTTP_BAD_REQUEST)
+            self.assertTrue('Non-integer X-Delete-At' in e.body)
+        else:
+            self.fail("Should have failed with HTTPBadRequest")
 
-        delete_at = str(int(ts + 100)) + '.1'
-        headers = {'X-Delete-At': delete_at,
-                   'X-Timestamp': str(ts)}
-        with self.assertRaises(HTTPException) as cm:
-            constraints.check_delete_headers(
+        t = str(int(time.time() + 100)) + '.1'
+        headers = {'X-Delete-At': t}
+        try:
+            resp = constraints.check_delete_headers(
                 Request.blank('/', headers=headers))
-        self.assertEqual(cm.exception.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('Non-integer X-Delete-At', cm.exception.body)
+        except HTTPException as e:
+            self.assertEqual(e.status_int, HTTP_BAD_REQUEST)
+            self.assertTrue('Non-integer X-Delete-At' in e.body)
+        else:
+            self.fail("Should have failed with HTTPBadRequest")
 
-        delete_at = str(int(ts - 1))
-        headers = {'X-Delete-At': delete_at,
-                   'X-Timestamp': str(ts)}
-        with self.assertRaises(HTTPException) as cm:
-            constraints.check_delete_headers(
+        t = str(int(time.time()))
+        headers = {'X-Delete-At': t}
+        try:
+            resp = constraints.check_delete_headers(
                 Request.blank('/', headers=headers))
-        self.assertEqual(cm.exception.status_int, HTTP_BAD_REQUEST)
-        self.assertIn('X-Delete-At in past', cm.exception.body)
+        except HTTPException as e:
+            self.assertEqual(e.status_int, HTTP_BAD_REQUEST)
+            self.assertTrue('X-Delete-At in past' in e.body)
+        else:
+            self.fail("Should have failed with HTTPBadRequest")
 
-    def test_check_delete_headers_removes_delete_after(self):
-        t = time.time()
-        headers = {'Content-Length': '0',
-                   'Content-Type': 'text/plain',
-                   'X-Delete-After': '42',
-                   'X-Delete-At': str(int(t) + 40),
-                   'X-Timestamp': str(t)}
-        req = Request.blank('/', headers=headers)
-        constraints.check_delete_headers(req)
-        self.assertNotIn('X-Delete-After', req.headers)
-        self.assertEqual(req.headers['X-Delete-At'], str(int(t) + 42))
+        t = str(int(time.time() - 1))
+        headers = {'X-Delete-At': t}
+        try:
+            resp = constraints.check_delete_headers(
+                Request.blank('/', headers=headers))
+        except HTTPException as e:
+            self.assertEqual(e.status_int, HTTP_BAD_REQUEST)
+            self.assertTrue('X-Delete-At in past' in e.body)
+        else:
+            self.fail("Should have failed with HTTPBadRequest")
 
     def test_check_delete_headers_sets_delete_at(self):
-        t = time.time()
-        expected = str(int(t) + 1000)
+        t = time.time() + 1000
         # check delete-at is passed through
         headers = {'Content-Length': '0',
                    'Content-Type': 'text/plain',
-                   'X-Delete-At': expected,
-                   'X-Timestamp': str(t)}
+                   'X-Delete-At': str(int(t))}
         req = Request.blank('/', headers=headers)
         constraints.check_delete_headers(req)
-        self.assertIn('X-Delete-At', req.headers)
-        self.assertEqual(req.headers['X-Delete-At'], expected)
+        self.assertTrue('X-Delete-At' in req.headers)
+        self.assertEqual(req.headers['X-Delete-At'], str(int(t)))
 
         # check delete-after is converted to delete-at
         headers = {'Content-Length': '0',
                    'Content-Type': 'text/plain',
-                   'X-Delete-After': '42',
-                   'X-Timestamp': str(t)}
+                   'X-Delete-After': '42'}
         req = Request.blank('/', headers=headers)
-        constraints.check_delete_headers(req)
-        self.assertIn('X-Delete-At', req.headers)
+        with mock.patch('time.time', lambda: t):
+            constraints.check_delete_headers(req)
+        self.assertTrue('X-Delete-At' in req.headers)
         expected = str(int(t) + 42)
         self.assertEqual(req.headers['X-Delete-At'], expected)
 
@@ -359,38 +355,66 @@ class TestConstraints(unittest.TestCase):
         headers = {'Content-Length': '0',
                    'Content-Type': 'text/plain',
                    'X-Delete-After': '42',
-                   'X-Delete-At': str(int(t) + 40),
-                   'X-Timestamp': str(t)}
+                   'X-Delete-At': str(int(t) + 40)}
         req = Request.blank('/', headers=headers)
-        constraints.check_delete_headers(req)
-        self.assertIn('X-Delete-At', req.headers)
+        with mock.patch('time.time', lambda: t):
+            constraints.check_delete_headers(req)
+        self.assertTrue('X-Delete-At' in req.headers)
         self.assertEqual(req.headers['X-Delete-At'], expected)
 
         headers = {'Content-Length': '0',
                    'Content-Type': 'text/plain',
                    'X-Delete-After': '42',
-                   'X-Delete-At': str(int(t) + 44),
-                   'X-Timestamp': str(t)}
+                   'X-Delete-At': str(int(t) + 44)}
         req = Request.blank('/', headers=headers)
-        constraints.check_delete_headers(req)
-        self.assertIn('X-Delete-At', req.headers)
+        with mock.patch('time.time', lambda: t):
+            constraints.check_delete_headers(req)
+        self.assertTrue('X-Delete-At' in req.headers)
         self.assertEqual(req.headers['X-Delete-At'], expected)
 
-    def test_check_dir(self):
-        self.assertFalse(constraints.check_dir('', ''))
-        with mock.patch("os.path.isdir", MockTrue()):
-            self.assertTrue(constraints.check_dir('/srv', 'foo/bar'))
+    def test_check_drive_invalid_path(self):
+        root = '/srv/'
+        with mock_check_drive() as mocks:
+            self.assertIsNone(constraints.check_dir(root, 'foo?bar'))
+            self.assertIsNone(constraints.check_mount(root, 'foo bar'))
+            self.assertIsNone(constraints.check_drive(root, 'foo/bar', True))
+            self.assertIsNone(constraints.check_drive(root, 'foo%bar', False))
+        self.assertEqual([], mocks['isdir'].call_args_list)
+        self.assertEqual([], mocks['ismount'].call_args_list)
 
-    def test_check_mount(self):
-        self.assertFalse(constraints.check_mount('', ''))
-        with mock.patch("swift.common.utils.ismount", MockTrue()):
-            self.assertTrue(constraints.check_mount('/srv', '1'))
-            self.assertTrue(constraints.check_mount('/srv', 'foo-bar'))
-            self.assertTrue(constraints.check_mount(
-                '/srv', '003ed03c-242a-4b2f-bee9-395f801d1699'))
-            self.assertFalse(constraints.check_mount('/srv', 'foo bar'))
-            self.assertFalse(constraints.check_mount('/srv', 'foo/bar'))
-            self.assertFalse(constraints.check_mount('/srv', 'foo?bar'))
+    def test_check_drive_ismount(self):
+        root = '/srv'
+        path = 'sdb1'
+        with mock_check_drive(ismount=True) as mocks:
+            self.assertIsNone(constraints.check_dir(root, path))
+            self.assertIsNone(constraints.check_drive(root, path, False))
+            self.assertEqual([mock.call('/srv/sdb1'), mock.call('/srv/sdb1')],
+                             mocks['isdir'].call_args_list)
+            self.assertEqual([], mocks['ismount'].call_args_list)
+        with mock_check_drive(ismount=True) as mocks:
+            self.assertEqual('/srv/sdb1', constraints.check_mount(root, path))
+            self.assertEqual('/srv/sdb1', constraints.check_drive(
+                root, path, True))
+            self.assertEqual([], mocks['isdir'].call_args_list)
+            self.assertEqual([mock.call('/srv/sdb1'), mock.call('/srv/sdb1')],
+                             mocks['ismount'].call_args_list)
+
+    def test_check_drive_isdir(self):
+        root = '/srv'
+        path = 'sdb2'
+        with mock_check_drive(isdir=True) as mocks:
+            self.assertEqual('/srv/sdb2', constraints.check_dir(root, path))
+            self.assertEqual('/srv/sdb2', constraints.check_drive(
+                root, path, False))
+            self.assertEqual([mock.call('/srv/sdb2'), mock.call('/srv/sdb2')],
+                             mocks['isdir'].call_args_list)
+            self.assertEqual([], mocks['ismount'].call_args_list)
+        with mock_check_drive(isdir=True) as mocks:
+            self.assertIsNone(constraints.check_mount(root, path))
+            self.assertIsNone(constraints.check_drive(root, path, True))
+            self.assertEqual([], mocks['isdir'].call_args_list)
+            self.assertEqual([mock.call('/srv/sdb2'), mock.call('/srv/sdb2')],
+                             mocks['ismount'].call_args_list)
 
     def test_check_float(self):
         self.assertFalse(constraints.check_float(''))
@@ -449,10 +473,10 @@ class TestConstraints(unittest.TestCase):
 
     def test_validate_constraints(self):
         c = constraints
-        self.assertGreater(c.MAX_META_OVERALL_SIZE, c.MAX_META_NAME_LENGTH)
-        self.assertGreater(c.MAX_META_OVERALL_SIZE, c.MAX_META_VALUE_LENGTH)
-        self.assertGreater(c.MAX_HEADER_SIZE, c.MAX_META_NAME_LENGTH)
-        self.assertGreater(c.MAX_HEADER_SIZE, c.MAX_META_VALUE_LENGTH)
+        self.assertTrue(c.MAX_META_OVERALL_SIZE > c.MAX_META_NAME_LENGTH)
+        self.assertTrue(c.MAX_META_OVERALL_SIZE > c.MAX_META_VALUE_LENGTH)
+        self.assertTrue(c.MAX_HEADER_SIZE > c.MAX_META_NAME_LENGTH)
+        self.assertTrue(c.MAX_HEADER_SIZE > c.MAX_META_VALUE_LENGTH)
 
     def test_check_account_format(self):
         req = Request.blank(
@@ -477,11 +501,14 @@ class TestConstraints(unittest.TestCase):
             req = Request.blank(
                 '/v/a/c/o', headers={
                     'X-Versions-Location': versions_location})
-            with self.assertRaises(HTTPException) as cm:
+            try:
                 constraints.check_container_format(
                     req, req.headers['X-Versions-Location'])
-            self.assertTrue(cm.exception.body.startswith(
-                'Container name cannot'))
+            except HTTPException as e:
+                self.assertTrue(e.body.startswith('Container name cannot'))
+            else:
+                self.fail('check_container_format did not raise error for %r' %
+                          req.headers['X-Versions-Location'])
 
     def test_valid_api_version(self):
         version = 'v1'
