@@ -14,7 +14,6 @@
 # limitations under the License.
 import json
 
-from test import unit
 import unittest
 import mock
 import os
@@ -25,8 +24,8 @@ from hashlib import md5
 from tempfile import mkdtemp
 import textwrap
 from os.path import dirname, basename
-from test.unit import (FakeLogger, patch_policies, make_timestamp_iter,
-                       DEFAULT_TEST_EC_TYPE)
+from test.unit import (debug_logger, patch_policies, make_timestamp_iter,
+                       DEFAULT_TEST_EC_TYPE, skip_if_no_xattrs)
 from swift.obj import auditor, replicator
 from swift.obj.diskfile import (
     DiskFile, write_metadata, invalidate_hash, get_data_dir,
@@ -63,10 +62,11 @@ def works_only_once(callable_thing, exception):
 class TestAuditor(unittest.TestCase):
 
     def setUp(self):
+        skip_if_no_xattrs()
         self.testdir = os.path.join(mkdtemp(), 'tmp_test_object_auditor')
         self.devices = os.path.join(self.testdir, 'node')
         self.rcache = os.path.join(self.testdir, 'object.recon')
-        self.logger = FakeLogger()
+        self.logger = debug_logger()
         rmtree(self.testdir, ignore_errors=1)
         mkdirs(os.path.join(self.devices, 'sda'))
         os.mkdir(os.path.join(self.devices, 'sdb'))
@@ -118,7 +118,6 @@ class TestAuditor(unittest.TestCase):
 
     def tearDown(self):
         rmtree(os.path.dirname(self.testdir), ignore_errors=1)
-        unit.xattr_data = {}
 
     def test_worker_conf_parms(self):
         def check_common_defaults():
@@ -246,7 +245,8 @@ class TestAuditor(unittest.TestCase):
                 writer.put(metadata)
                 writer.commit(Timestamp(timestamp))
 
-            auditor_worker = auditor.AuditorWorker(self.conf, FakeLogger(),
+            self.logger.clear()
+            auditor_worker = auditor.AuditorWorker(self.conf, self.logger,
                                                    self.rcache, self.devices)
             self.assertEqual(0, auditor_worker.quarantines)  # sanity check
             auditor_worker.object_audit(
@@ -600,20 +600,19 @@ class TestAuditor(unittest.TestCase):
         self.assertEqual(auditor_worker.stats_buckets['OVER'], 2)
 
     def test_object_run_logging(self):
-        logger = FakeLogger()
-        auditor_worker = auditor.AuditorWorker(self.conf, logger,
+        auditor_worker = auditor.AuditorWorker(self.conf, self.logger,
                                                self.rcache, self.devices)
         auditor_worker.audit_all_objects(device_dirs=['sda'])
-        log_lines = logger.get_lines_for_level('info')
+        log_lines = self.logger.get_lines_for_level('info')
         self.assertGreater(len(log_lines), 0)
         self.assertTrue(log_lines[0].index('ALL - parallel, sda'))
 
-        logger = FakeLogger()
-        auditor_worker = auditor.AuditorWorker(self.conf, logger,
+        self.logger.clear()
+        auditor_worker = auditor.AuditorWorker(self.conf, self.logger,
                                                self.rcache, self.devices,
                                                zero_byte_only_at_fps=50)
         auditor_worker.audit_all_objects(device_dirs=['sda'])
-        log_lines = logger.get_lines_for_level('info')
+        log_lines = self.logger.get_lines_for_level('info')
         self.assertGreater(len(log_lines), 0)
         self.assertTrue(log_lines[0].index('ZBF - sda'))
 
@@ -906,7 +905,7 @@ class TestAuditor(unittest.TestCase):
             self.disk_file.delete(ts_tomb)
             # this get_hashes call will truncate the invalid hashes entry
             self.disk_file.manager.get_hashes(
-                self.devices + '/sda', '0', [], self.disk_file.policy)
+                'sda', '0', [], self.disk_file.policy)
         suffix = basename(dirname(self.disk_file._datadir))
         part_dir = dirname(dirname(self.disk_file._datadir))
         # sanity checks...
@@ -984,8 +983,7 @@ class TestAuditor(unittest.TestCase):
 
     def _test_expired_object_is_ignored(self, zero_byte_fps):
         # verify that an expired object does not get mistaken for a tombstone
-        audit = auditor.ObjectAuditor(self.conf)
-        audit.logger = FakeLogger()
+        audit = auditor.ObjectAuditor(self.conf, logger=self.logger)
         audit.log_time = 0
         now = time.time()
         write_diskfile(self.disk_file, Timestamp(now - 20),
@@ -1011,7 +1009,7 @@ class TestAuditor(unittest.TestCase):
 
         # this get_hashes call will truncate the invalid hashes entry
         self.disk_file.manager.get_hashes(
-            self.devices + '/sda', '0', [], self.disk_file.policy)
+            'sda', '0', [], self.disk_file.policy)
         with open(hash_invalid, 'rb') as fp:
             self.assertEqual('', fp.read().strip('\n'))  # sanity check
 
